SearchMatch class
Represents a successful match of a pattern in a text.
Constructors
- SearchMatch({required int index, required int length, required SearchAlgorithm algorithm})
-
Creates a new SearchMatch.
const
Properties
- algorithm → SearchAlgorithm
-
The algorithm that found this match.
final
- end → int
-
The exclusive end index of the match (index + length).
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- index → int
-
The start index of the match in the text.
final
- length → int
-
The length of the match.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override